from flask import Flask, render_template, redirect, url_for, flash, request, send_file, send_from_directory
from container import Container
from werkzeug.utils import secure_filename
from urllib import parse
import os

app = Flask(__name__)

with open('sas_url', 'r') as file:
    sas_url = file.read()

parsed_url = parse.urlsplit(sas_url)
url = f"{parsed_url.scheme}://{parsed_url.netloc}{parsed_url.path}"
query_string = parsed_url.query


@app.route("/")
def index():
    container = Container(sas_url)
    blobs = container.get_list_of_blobs()
    print(blobs)
    # return f"{blobs}"
    return render_template('index.html', blobs=blobs, blobs_len=len(blobs), container_url=url, query_string=query_string)


@app.route('/upload')
def upload():
    container = Container(sas_url)
    container.upload_blob_to_container("./test_file.txt")
    return redirect(url_for('index'))


@app.route('/del/<name>')
def del_blob(name):
    container = Container(sas_url)
    container.delete_blob_from_container(name)
    return redirect(url_for('index'))


@app.route('/download/<name>')
def download_blob(name):
    container = Container(sas_url)
    container.download_blob_from_container(name, name)
    return send_from_directory(directory='.', path='./', filename=name, as_attachment=True)


@app.route('/del_all')
def del_all():
    container = Container(sas_url)
    container.delete_all_blobs()
    return redirect(url_for('index'))


@app.route('/upload-file', methods=['POST'])
def uploadFile():
    if request.method == 'POST':
        file = request.files['file']
        if file:
            filename = secure_filename(file.filename)
            file.save(filename)
            print(f"filename = {filename}")
            print(f"uploadfile = {file}")
            container = Container(sas_url)
            container.upload_blob_to_container(filename)
            os.remove(filename)
    return redirect(url_for('index'))


if __name__ == '__main__':
    app.run(host="0.0.0.0", port=5000, debug=False)
