import uuid, os
from datetime import datetime
from azure.storage.blob import ContainerClient
from urllib import parse


class Container():

    def __init__(self, sas_url):
        self.sas_url = sas_url
        self.parsed_url = parse.urlsplit(self.sas_url)
        self.url = f"{self.parsed_url.scheme}://{self.parsed_url.netloc}{self.parsed_url.path}"
        self.query_string = self.parsed_url.query

    def get_container_client(self):
        return ContainerClient.from_container_url(self.sas_url)

    def delete_blob_from_container(self, blobname):
        container_client = self.get_container_client()
        blob_client = container_client.get_blob_client(blobname)
        blob_client.delete_blob()

    def delete_all_blobs(self):
        blobs = self.get_list_of_blobs()
        for blob in blobs:
            self.delete_blob_from_container(blob)

    def check_if_file_exists(self, name):
        blobs = self.get_list_of_blobs()
        if name not in blobs:
            return False
        return True

    def download_blob_from_container(self, blob_name, dest_file):
        container_client = self.get_container_client()
        blob_client = container_client.get_blob_client(blob_name)
        with open(dest_file, "wb") as my_blob:
            download_stream = blob_client.download_blob()
            download_stream.readinto(my_blob)

    def get_list_of_blobs(self):
        container = self.get_container_client()
        blobs_list_response = container.list_blobs()
        blob_list = []

        for blob in blobs_list_response:
            blob_list.append(blob['name'])

        return blob_list

    def upload_blob_to_container(self, file):
        container_client = self.get_container_client()
        name = os.path.basename(file)
        if self.check_if_file_exists(name):
            split_name = name.split('.')
            now = datetime.now()
            split_name[0] = split_name[0] + '-' + now.strftime("%m-%d-%Y-%H-%M-%S")
            name = split_name[0] + '.' + split_name[-1]

        # name = str(uuid.uuid4())
        with open(file, "rb") as data:
            blob_client = container_client.upload_blob(name=name, data=data)

        properties = blob_client.get_blob_properties()
        return properties
